@@ -42,10 +42,10 @@ def print_subdomain_result(url, ip, http_connection_headers=None, nearby=None, s
 def unvisited_closure():
     visited = set()
 
-    def inner(l):
+    def inner(inner_visited):
         nonlocal visited
-        result = set(l).difference(visited)
-        visited.update(l)
+        result = set(inner_visited).difference(visited)
+        visited.update(inner_visited)
         return result
 
     return inner
@@ -58,24 +58,15 @@ def find_subdomain_list_file(filename):
     if os.path.exists(filename_path):
         return os.path.abspath(filename_path)
 
-    try:
-        import pkg_resources
-    except ImportError:
-        return filename
-
     # If the relative check failed then attempt to find the list file
     # in the pip package directory. This will typically happen on pip package
     # installs (duh)
-    package_filename_path = os.path.join("lists", filename)
     try:
-        full_package_path = pkg_resources.resource_filename(
-            "fierce",
-            package_filename_path
-        )
+        from fierce import lists
     except ImportError:
         return filename
 
-    return full_package_path
+    return str(lists.CURDIR / filename)
 
 
 def head_request(url, timeout=2):
@@ -319,8 +310,12 @@ def fierce(**kwargs):
     if soa:
         soa_mname = soa[0].mname
         master = query(resolver, soa_mname, record_type='A', tcp=kwargs["tcp"])
-        master_address = master[0].address
-        print("SOA: {} ({})".format(soa_mname, master_address))
+        if master:
+            master_address = master[0].address
+            print("SOA: {} ({})".format(soa_mname, master_address))
+        else:
+            print("SOA: failure")
+            fatal("Failed to lookup NS/SOA, Domain does not exist")
     else:
         print("SOA: failure")
         fatal("Failed to lookup NS/SOA, Domain does not exist")
@@ -331,7 +326,7 @@ def fierce(**kwargs):
         pprint.pprint({k: v.to_text(k) for k, v in zone.items()})
         return
 
-    random_subdomain = str(random.randint(1e10, 1e11))  # noqa DUO102, non-cryptographic random use
+    random_subdomain = str(random.randint(int(1e10), int(1e11)))
     random_domain = concatenate_subdomains(domain, [random_subdomain])
     wildcard = query(resolver, random_domain, record_type='A', tcp=kwargs["tcp"])
     wildcard_ips = set(rr.address for rr in wildcard.rrset) if wildcard else set()
